@@ -2,7 +2,7 @@
 This is a replacement event loop and policy for asyncio that uses FPGA time,
 rather than native python time.
 """
-from asyncio.events import BaseDefaultEventLoopPolicy
+from asyncio.events import AbstractEventLoopPolicy
 from asyncio import SelectorEventLoop, set_event_loop_policy
 from wpilib import Timer
 
@@ -13,7 +13,7 @@ class FPGATimedEventLoop(SelectorEventLoop):
         return Timer.getFPGATimestamp()
 
 
-class FPGATimedEventLoopPolicy(BaseDefaultEventLoopPolicy):
+class FPGATimedEventLoopPolicy(AbstractEventLoopPolicy):
     """An asyncio event loop policy that uses FPGATimedEventLoop"""
     _loop_factory = FPGATimedEventLoop
 
